# ARLQ, another rogue-like quest game

ARLQ (Another Rogue-Like Quest) game created as an experiment in developing code and manuals with humans and ChatGPT.

Please visit the homepage, [https://github.com/tos-kamiya/arlq/](https://github.com/tos-kamiya/arlq/), for more information.

![](https://github.com/tos-kamiya/arlq/blob/main/screenshot.png?raw=True)

